@@ -80,7 +80,7 @@ folders_update (const gchar *root,
 		goto done;
 	}
 
-	while ((line = camel_stream_buffer_read_line ((CamelStreamBuffer *)in, cancellable, NULL))) {
+	while ((line = camel_stream_buffer_read_line ((CamelStreamBuffer *) in, cancellable, NULL))) {
 		gint copy = TRUE;
 
 		switch (mode) {
@@ -173,10 +173,10 @@ fill_fi (CamelStore *store,
 		   scan of all messages for their status flags.  But its probably not worth
 		   it as we need to read the top of every file, i.e. very very slow */
 
-		root = camel_local_store_get_toplevel_dir ((CamelLocalStore *)store);
+		root = camel_local_store_get_toplevel_dir ((CamelLocalStore *) store);
 		path = g_strdup_printf("%s/%s.ev-summary", root, fi->full_name);
 		folderpath = g_strdup_printf("%s/%s", root, fi->full_name);
-		s = (CamelFolderSummary *)camel_mh_summary_new (NULL, path, folderpath, NULL);
+		s = (CamelFolderSummary *) camel_mh_summary_new (NULL, path, folderpath, NULL);
 		if (camel_folder_summary_header_load_from_db (s, store, fi->full_name, NULL) != -1) {
 			fi->unread = s->unread_count;
 			fi->total = s->saved_count;
@@ -194,7 +194,6 @@ fill_fi (CamelStore *store,
 
 static CamelFolderInfo *
 folder_info_new (CamelStore *store,
-                 CamelURL *url,
                  const gchar *root,
                  const gchar *path,
                  guint32 flags,
@@ -206,17 +205,12 @@ folder_info_new (CamelStore *store,
 
 	base = strrchr (path, '/');
 
-	camel_url_set_fragment (url, path);
-
 	/* Build the folder info structure. */
 	fi = camel_folder_info_new ();
-	fi->uri = camel_url_to_string (url, 0);
 	fi->full_name = g_strdup (path);
-	fi->name = g_strdup (base?base+1:path);
+	fi->display_name = g_strdup (base?base+1:path);
 	fill_fi (store, fi, flags, cancellable);
 
-	d(printf("New folderinfo:\n '%s'\n '%s'\n '%s'\n", fi->full_name, fi->uri, fi->path));
-
 	return fi;
 }
 
@@ -230,7 +224,6 @@ struct _inode {
  * root and path should have a trailing "/" if they aren't empty. */
 static void
 recursive_scan (CamelStore *store,
-                CamelURL *url,
                 CamelFolderInfo **fip,
                 CamelFolderInfo *parent,
                 GHashTable *visited,
@@ -251,7 +244,7 @@ recursive_scan (CamelStore *store,
 		fullpath = alloca (strlen (root) + strlen (path) + 2);
 		sprintf (fullpath, "%s/%s", root, path);
 	} else
-		fullpath = (gchar *)root;
+		fullpath = (gchar *) root;
 
 	if (g_stat (fullpath, &st) == -1 || !S_ISDIR (st.st_mode))
 		return;
@@ -268,7 +261,7 @@ recursive_scan (CamelStore *store,
 	g_hash_table_insert (visited, inew, inew);
 
 	/* link in ... */
-	fi = folder_info_new (store, url, root, path, flags, cancellable);
+	fi = folder_info_new (store, root, path, flags, cancellable);
 	fi->parent = parent;
 	fi->next = *fip;
 	*fip = fi;
@@ -294,10 +287,10 @@ recursive_scan (CamelStore *store,
 			/* otherwise, treat at potential node, and recurse, a bit more expensive than needed, but tough! */
 			if (path[0]) {
 				tmp = g_strdup_printf("%s/%s", path, d->d_name);
-				recursive_scan (store, url, &fi->child, fi, visited, root, tmp, flags, cancellable);
+				recursive_scan (store, &fi->child, fi, visited, root, tmp, flags, cancellable);
 				g_free (tmp);
 			} else {
-				recursive_scan (store, url, &fi->child, fi, visited, root, d->d_name, flags, cancellable);
+				recursive_scan (store, &fi->child, fi, visited, root, d->d_name, flags, cancellable);
 			}
 		}
 
@@ -308,7 +301,6 @@ recursive_scan (CamelStore *store,
 /* scan a .folders file */
 static void
 folders_scan (CamelStore *store,
-              CamelURL *url,
               const gchar *root,
               const gchar *top,
               CamelFolderInfo **fip,
@@ -337,7 +329,7 @@ folders_scan (CamelStore *store,
 	visited = g_hash_table_new (g_str_hash, g_str_equal);
 	folders = g_ptr_array_new ();
 
-	while ( (len = camel_stream_buffer_gets ((CamelStreamBuffer *)in, line, sizeof (line), cancellable, NULL)) > 0) {
+	while ( (len = camel_stream_buffer_gets ((CamelStreamBuffer *) in, line, sizeof (line), cancellable, NULL)) > 0) {
 		/* ignore blank lines */
 		if (len <= 1)
 			continue;
@@ -377,7 +369,7 @@ folders_scan (CamelStore *store,
 
 		path = g_strdup_printf("%s/%s", root, line);
 		if (g_stat (path, &st) == 0 && S_ISDIR (st.st_mode)) {
-			fi = folder_info_new (store, url, root, line, flags, cancellable);
+			fi = folder_info_new (store, root, line, flags, cancellable);
 			g_ptr_array_add (folders, fi);
 		}
 		g_free (path);
@@ -387,7 +379,7 @@ folders_scan (CamelStore *store,
 		*fip = camel_folder_info_build(folders, top, '/', TRUE);
 	g_ptr_array_free (folders, TRUE);
 
-	g_hash_table_foreach (visited, (GHFunc)g_free, NULL);
+	g_hash_table_foreach (visited, (GHFunc) g_free, NULL);
 	g_hash_table_destroy (visited);
 
 	g_object_unref (in);
@@ -416,25 +408,23 @@ inode_free (gpointer k, gpointer v, gpointer d)
 	g_free (k);
 }
 
-static gboolean
-mh_folder_store_construct (CamelService *service,
-                           CamelSession *session,
-                           CamelProvider *provider,
-                           CamelURL *url,
-                           GError **error)
+static void
+mh_store_constructed (GObject *object)
 {
-	CamelServiceClass *service_class;
-	CamelMhStore *mh_store = (CamelMhStore *)service;
+	CamelMhStore *mh_store;
+	CamelService *service;
+	CamelURL *url;
 
-	/* Chain up to parent's construct() method. */
-	service_class = CAMEL_SERVICE_CLASS (camel_mh_store_parent_class);
-	if (!service_class->construct (service, session, provider, url, error))
-		return FALSE;
+	mh_store = CAMEL_MH_STORE (object);
+
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (camel_mh_store_parent_class)->constructed (object);
+
+	service = CAMEL_SERVICE (object);
+	url = camel_service_get_camel_url (service);
 
 	if (camel_url_get_param(url, "dotfolders"))
 		mh_store->flags |= CAMEL_MH_DOTFOLDERS;
-
-	return TRUE;
 }
 
 static CamelFolder *
@@ -488,8 +478,8 @@ mh_store_get_folder_sync (CamelStore *store,
 
 		/* add to .folders if we are supposed to */
 		/* FIXME: throw exception on error */
-		if (((CamelMhStore *)store)->flags & CAMEL_MH_DOTFOLDERS)
-			folders_update (((CamelLocalStore *)store)->toplevel_dir, UPDATE_ADD, folder_name, NULL, cancellable);
+		if (((CamelMhStore *) store)->flags & CAMEL_MH_DOTFOLDERS)
+			folders_update (((CamelLocalStore *) store)->toplevel_dir, UPDATE_ADD, folder_name, NULL, cancellable);
 	} else if (!S_ISDIR (st.st_mode)) {
 		g_set_error (
 			error, CAMEL_STORE_ERROR,
@@ -521,22 +511,22 @@ mh_store_get_folder_info_sync (CamelStore *store,
 {
 	CamelFolderInfo *fi = NULL;
 	CamelURL *url;
-	gchar *root;
 
-	root = ((CamelService *)store)->url->path;
-
-	url = camel_url_copy (((CamelService *) store)->url);
+	url = camel_service_get_camel_url (CAMEL_SERVICE (store));
 
 	/* use .folders if we are supposed to */
-	if (((CamelMhStore *)store)->flags & CAMEL_MH_DOTFOLDERS) {
-		folders_scan (store, url, root, top, &fi, flags, cancellable);
+	if (((CamelMhStore *) store)->flags & CAMEL_MH_DOTFOLDERS) {
+		folders_scan (
+			store, url->path, top, &fi, flags, cancellable);
 	} else {
 		GHashTable *visited = g_hash_table_new (inode_hash, inode_equal);
 
 		if (top == NULL)
 			top = "";
 
-		recursive_scan (store, url, &fi, NULL, visited, root, top, flags, cancellable);
+		recursive_scan (
+			store, &fi, NULL, visited, url->path,
+			top, flags, cancellable);
 
 		/* if we actually scanned from root, we have a "" root node we dont want */
 		if (fi != NULL && top[0] == 0) {
@@ -552,8 +542,6 @@ mh_store_get_folder_info_sync (CamelStore *store,
 		g_hash_table_destroy (visited);
 	}
 
-	camel_url_free (url);
-
 	return fi;
 }
 
@@ -589,8 +577,8 @@ mh_store_delete_folder_sync (CamelStore *store,
 	g_free (name);
 
 	/* remove from .folders if we are supposed to */
-	if (((CamelMhStore *)store)->flags & CAMEL_MH_DOTFOLDERS)
-		folders_update (((CamelLocalStore *)store)->toplevel_dir, UPDATE_REMOVE, folder_name, NULL, cancellable);
+	if (((CamelMhStore *) store)->flags & CAMEL_MH_DOTFOLDERS)
+		folders_update (((CamelLocalStore *) store)->toplevel_dir, UPDATE_REMOVE, folder_name, NULL, cancellable);
 
 	/* Chain up to parent's delete_folder() method. */
 	store_class = CAMEL_STORE_CLASS (camel_mh_store_parent_class);
@@ -613,9 +601,9 @@ mh_store_rename_folder_sync (CamelStore *store,
 		store, old, new, cancellable, error))
 		return FALSE;
 
-	if (((CamelMhStore *)store)->flags & CAMEL_MH_DOTFOLDERS) {
+	if (((CamelMhStore *) store)->flags & CAMEL_MH_DOTFOLDERS) {
 		/* yeah this is messy, but so is mh! */
-		folders_update (((CamelLocalStore *)store)->toplevel_dir, UPDATE_RENAME, old, new, cancellable);
+		folders_update (((CamelLocalStore *) store)->toplevel_dir, UPDATE_RENAME, old, new, cancellable);
 	}
 
 	return TRUE;
@@ -624,11 +612,11 @@ mh_store_rename_folder_sync (CamelStore *store,
 static void
 camel_mh_store_class_init (CamelMhStoreClass *class)
 {
-	CamelServiceClass *service_class;
+	GObjectClass *object_class;
 	CamelStoreClass *store_class;
 
-	service_class = CAMEL_SERVICE_CLASS (class);
-	service_class->construct = mh_folder_store_construct;
+	object_class = G_OBJECT_CLASS (class);
+	object_class->constructed = mh_store_constructed;
 
 	store_class = CAMEL_STORE_CLASS (class);
 	store_class->get_folder_sync = mh_store_get_folder_sync;
